@@ -85,6 +85,8 @@ public:
 
     idx_t size() const override { return nb_edges_; }
 
+    const Grid& grid() const override;
+
     Field lonlat() const override;
 
     Field global_index() const override;
@@ -105,6 +107,7 @@ private:  // methods
     size_t footprint() const override;
 
 private:                           // data
+    mutable Grid grid_;
     Mesh mesh_;                    // non-const because functionspace may modify mesh
     mesh::HybridElements& edges_;  // non-const because functionspace may modify mesh
     idx_t nb_levels_;
