@@ -58,8 +58,18 @@ private:
 
     void generate_mesh(const StructuredGrid&, const grid::Distribution&, Mesh& m) const;
 
+    gidx_t match_node_idx(const gidx_t& gidx, const int ns) const;
+    gidx_t idx_xy_to_x(const int xidx, const int yidx, const int ns) const;
+    gidx_t up_idx(const int xidx, const int yidx, const int ns) const;
+    gidx_t down_idx(const int xidx, const int yidx, const int ns) const;
+    gidx_t right_idx(const int xidx, const int yidx, const int ns) const;
+    gidx_t pentagon_right_idx(const int xidx, const int yidx, const int ns) const;
+
 private:
     util::Metadata options;
+    mutable gidx_t nb_points_;
+    mutable gidx_t nb_nodes_;
+    mutable int nb_pole_nodes_;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
